#
# spec file for package syncplay
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           syncplay
Version:        1.7.4
Release:        1.1
Summary:        Client/server to synchronize media playback on mpv/VLC on multiple computers
License:        Apache-2.0
URL:            https://syncplay.pl/
Source:         https://github.com/Syncplay/syncplay/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
#PATCH-FIX-SUSE switch-env-to-python.patch nopeinomicon@posteo.net -- Sets interpreter to python3 as opposed to env python3
Patch0:         switch-env-to-python.patch
BuildRequires:  hicolor-icon-theme
BuildRequires:  make
BuildRequires:  python-rpm-generators
BuildRequires:  update-desktop-files
BuildArch:      noarch
%{?python_enable_dependency_generator}

%description
Client/server to synchronize media playback on mpv/VLC on multiple
computers.

%package common
Summary:        The common files for the Syncplay client and server

%description common
The common files for the Syncplay client and server

%package client
Summary:        Client to synchronize media playback on mpv/VLC on multiple computers
Requires:       %{name}-common
Requires:       python3-Twisted >= 16.4.0
Recommends:     python3-certifi >= 2018.11.29
Recommends:     python3-idna >= 0.6
Recommends:     python3-pem >= 21.2.0
Recommends:     python3-pyOpenSSL >= 16.0.0
Recommends:     python3-service_identity
Suggests:       mpv
%if 0%{?suse_version} > 1500
Recommends:     python3-pyside6
%else
Recommends:     python3-pyside2 >= 5.12.0
%endif

%description client
The client application for Syncplay, allows you to play media in
synchronization with other users around the world, making movie
nights even across countries possible.

%package server
Summary:        Server for the Syncplay media synchronizing application
Requires:       %{name}-common
Requires:       python3-Twisted >= 16.4.0
Recommends:     python3-certifi >= 2018.11.29
Recommends:     python3-idna >= 0.6
Recommends:     python3-pem >= 21.2.0
Recommends:     python3-pyOpenSSL >= 16.0.0
Recommends:     python3-service_identity

%description server
The server applciation for Syncplay, acts as a hub for other users
to connect to and watch videos together in synchronization.

%prep
%autosetup -p1

%build
# Nothing to build

%install
%make_install
%suse_update_desktop_file -r %{name} AudioVideo Player Network
%suse_update_desktop_file -r %{name}-server AudioVideo Network

%files common
%license LICENSE
%doc README.md
%dir %{_prefix}/lib/syncplay/
%dir %{_prefix}/lib/syncplay/syncplay/
%{_prefix}/lib/syncplay/syncplay/*
%{_datadir}/icons/hicolor/*/apps/syncplay.png
%{_datadir}/pixmaps/syncplay.png

%files client
%license LICENSE
%doc README.md
%{_bindir}/syncplay
%{_prefix}/lib/syncplay/syncplayClient.py
%{_datadir}/applications/syncplay.desktop
%{_mandir}/man1/syncplay.1%{?ext_man}

%files server
%license LICENSE
%doc README.md
%{_bindir}/syncplay-server
%{_prefix}/lib/syncplay/syncplayServer.py
%{_datadir}/applications/syncplay-server.desktop
%{_mandir}/man1/syncplay-server.1%{?ext_man}

%changelog
* Sat Apr 26 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.7.4:
  * Added ‘readiness override’ feature. If you can control a remove, you can
    set someone a ready or not ready through the context menu in the list of
    who is playing what. Only works if the server is running v.1.7.4, but
    can change status for people using older clients. Adds the
    folderSearchWarningThreshold’ setting to the Synclay INI.
  * Allow folder search timings to be tweaked for better FTP rmount support,
    adding ‘folderSearchFirstFileTimeout’, ‘folderSearchTimeout’ and
    ‘folderSearchDoubleCheckInterval’ settings to the Synclay INI
  * Fix position not changing when playlist changed in mpv error
  * Update Turkish translation
  * Adjust QSplitter style
  * Improved handling of big media directories
  * Fix some rewind issues relating to file loads / playlist changes
  * Set mpv.net ‘auto load folder’ setting to false to fix playlist
    advancement bug
* Thu May  9 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.7.3:
  * Fix MPV socket getting created in CWD folder rand only create second pipe
    if manually specified using input-ipc-server per player argument
  * Add support for mpv installed from Microsoft store
  * Fix invalid string escapes
- Update to version 1.7.2:
  * Add new per-user mpv.net path
  * Pass input-ipc-server player argument to mpv
  * Fix --no-gui PySide dependency issue on non-Windows OS
  * Fixed German Translation and added more Translated Strings
  * Remove adding executable permissions to .desktop files
  * Allow player arguments with spaces/quotes
  * Fixed MPC-HC hanging issue involving 'LRESULT' error
  * Don't log all 32/64-bit cryptography 'frozen zipimport' errors
  * Provide more information on PySide load failure
  * Avoid error when closing Syncplay before loadDelayedPath is complete
* Sat Feb  3 2024 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.7.1:
  * Headline changes:
  - Adding --interface-ipv4 and --interface-ipv6 command line
    switches to server to allow better control over binding to
    interfaces.
  * Tweaks:
  - Re-work readiness notifications for non-operators.
  - Show current offset in set offset dialogue.
  * Bug fixes and maintenance:
  - Fix GUI TypeError.
  - Playlist restoration should not undo clearing actions.
  - Support player arguments like –no-border in mpv.
  - Ensure MPC-HC resets position on playlist change.
  - Define desktop filename for Wayland compliance to fix icon.
  - Fix offset sub-second precision bug.
  - Remove broken setAlignment calls.
  - Don’t pass empty model to QCompleter.
- Set `BuildArch` to `noarch`.
* Sun Apr 16 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.7.0:
  * Headline additions:
  - Add room permanence option to server.
  - Add playlist-related commands:
    + /qa [file/url] – add file or url to bottom of playlist;
    + /qas [file/url] – add file or url to bottom of playlist and
    select it;
    + /ql – show the current playlist;
    + /qs [index] – select given entry in the playlist;
    + /qn – select next entry in the playlist;
    + /qd [index] – delete the given entry from the playlist.
  * Other improvements:
  - Allow playlists to be played from network.
  - If LANG parameter is set in setup, don’t show language
    dialogue.
  - Print timestamp when pausing.
  - More verbose connection error messages.
  - Remove mpv fallback warning spam.
  - Console: Document setting offset in help.
  - Update translations.
  * Bug Fixes:
  - Restore server-side playlist on reconnect.
  - Trusted Domains: Allow trusting a domain regardless of HTTP
    basic auth credentials.
  - Fix room name case sensitivity UI issue.
  - Remove redundant help button from dialogues.
  - Fix server argument max-username-length not working.
  - Fix disconnected monitor bug.
  - Fix converting lines to array.
  - Explicitly pass certifi as trustRoot for Twisted.
  - Don’t detect SMPlayer as mplayer2.
  - Add/fix wildcard matching of trusted subdomains.
  - Fix localhost connection breaking mpv chat.
  - Fix mpv quit message.
  - Revert default max username length to 16 chars.
  - Fix dark mode detection by moving to darkdetect v0.7.1.
  * Maintenance:
  - Remove Encoding from .desktop files as it’s deprecated now
    and add Keywords entry to .desktop files.
  - Correct persistence argument type.
  - Log –debug as UTF-8 to fix charmap mapping.
  - Add deprecation notice for offset help.
* Thu Sep  2 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 1.6.9
  * Removed references to discontinued IRC channel
  * Update and improve Brazilian Portuguese translation
* Sat Jul 24 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.6.8:
  * Improve playlist advancement for mpv and VLC.
  * Fix VLC connection issues.
  * Update mpv vendor code.
  * Add more MPC-HC paths.
  * Fix issues with per-player arguments.
  * Add some input characters for mpv, some of which might work.
  * (Hopefully) ignore benign AA_EnableHighDpiScaling error.
  * Add manpages.
  * Update translations.
- Remove the broken and unnecessary "python" requirement.
- Remove the Qt requirement from the server package.
- Use a ready tarball instead of generating it from git.
* Fri Dec 18 2020 Emily Roberts <nopeinomicon@posteo.net>
- Cleanup .spec file
  * Remove obsolete macros
  * Use spec-cleaner
  * Correct dependencies for subpackages
* Fri Dec 18 2020 Emily Roberts <nopeinomicon@posteo.net>
- Attempt to fix desktop file categories
- Add license and readme for all packages
* Fri Dec 18 2020 Emily Roberts <nopeinomicon@posteo.net>
- Initial package build
